==> captchetat-1.0.0.tar.gz: captchetat/src/Controller/CaptchetatController.php <==
<?php

namespace Drupal\captchetat\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Response;

/**
 * Class CaptchetatController.
 */
class CaptchetatController extends ControllerBase {

  /**
   * Returns true if API is up or false if API is down.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   */
  public function healthCheck() {
    $token = $this->generateApiToken();
    $config = \Drupal::configFactory()->getEditable('captchetat.settings');
    $url = $config->get('api_url') . '/piste/captcha/healthcheck';

    $ch = curl_init($url);
    $headers = [
      "Authorization: Bearer $token",
    ];

    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
      echo 'Curl error: ' . curl_error($ch);
    }

    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
    curl_close($ch);

    return new Response($response);
  }

  /**
   * Returns the captchetat token.
   *
   * @return string
   */
  public function generateApiToken() {
    $config = \Drupal::configFactory()->getEditable('captchetat.settings');
    $client_id = $config->get('client_id');
    $client_secret = $config->get('client_secret');
    $url = $config->get('oauth_url') . '/api/oauth/token';

    $data = [
      'grant_type' => 'client_credentials',
      'client_id' => $client_id,
      'client_secret' => $client_secret,
      'scope' => 'piste.captchetat',
    ];
    $ch = curl_init($url);

    curl_setopt($ch, CURLOPT_POST, TRUE);
    curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/x-www-form-urlencoded']);
    curl_setopt($ch, CURLOPT_TIMEOUT, 3600);

    $response = curl_exec($ch);
    $result = json_decode($response);
    $token = $result->access_token;

    if (curl_errno($ch)) {
      echo 'Curl error: ' . curl_error($ch);
    }

    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
    curl_close($ch);

    return $token;
  }

  /**
   * Gets Captcha from API Captchetat.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   */
  public function getCaptcha() {
    $token = $this->generateApiToken();
    $config = \Drupal::configFactory()->getEditable('captchetat.settings');
    $request_uri = \Drupal::request()->getRequestUri();
    $query_params = explode('?', $request_uri)[1];
    $url = $config->get('api_url') . '/piste/captcha/simple-captcha-endpoint?' . $query_params;
    $ch = curl_init();
    $headers = [
      "Authorization: Bearer $token",
    ];

    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
      echo 'Curl error: ' . curl_error($ch);
    }

    curl_close($ch);

    return new Response($response);
  }

  /**
   * Validates the user submission.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   */
  public function validationCaptcha() {
    $token = $this->generateApiToken();
    $config = \Drupal::configFactory()->getEditable('captchetat.settings');
    $request = \Drupal::request();
    $payload = $request->getContent();
    $decoded_payload = json_decode($payload, TRUE);
    $url = $config->get('api_url') . '/piste/captcha/valider-captcha';

    $data = [
      'id' => $decoded_payload['captchaId'],
      'code' => $decoded_payload['userEnteredCaptchaCode'],
    ];

    $jsonData = json_encode($data);

    $headers = [
      "Authorization: Bearer $token",
      'Content-Type: application/json',
    ];

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonData);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
      echo 'Curl error: ' . curl_error($ch);
    }

    curl_close($ch);

    return new Response($response);
  }

}

==> captchetat-1.0.2.tar.gz: captchetat/src/Controller/CaptchetatController.php <==
<?php

namespace Drupal\captchetat\Controller;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * This controller provides different connections to API CaptchEtat.
 */
class CaptchetatController extends ControllerBase {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new CaptchetatController object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Returns if API is up or down.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   HTTP Response.
   */
  public function healthCheck() {
    $token = $this->generateApiToken();
    $config = $this->configFactory->getEditable('captchetat.settings');
    $url = $config->get('api_url') . '/piste/captcha/healthcheck';

    $ch = curl_init($url);
    $headers = [
      "Authorization: Bearer $token",
    ];

    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
      echo 'Curl error: ' . curl_error($ch);
    }

    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
    curl_close($ch);

    return new Response($response);
  }

  /**
   * Returns the captchetat token.
   *
   * @return string
   *   token provided by API CaptchEtat.
   */
  public function generateApiToken() {
    $config = $this->configFactory->getEditable('captchetat.settings');
    $client_id = $config->get('client_id');
    $client_secret = $config->get('client_secret');
    $url = $config->get('oauth_url') . '/api/oauth/token';

    $data = [
      'grant_type' => 'client_credentials',
      'client_id' => $client_id,
      'client_secret' => $client_secret,
      'scope' => 'piste.captchetat',
    ];
    $ch = curl_init($url);

    curl_setopt($ch, CURLOPT_POST, TRUE);
    curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/x-www-form-urlencoded']);
    curl_setopt($ch, CURLOPT_TIMEOUT, 3600);

    $response = curl_exec($ch);
    $result = json_decode($response);
    $token = $result->access_token;

    if (curl_errno($ch)) {
      echo 'Curl error: ' . curl_error($ch);
    }

    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
    curl_close($ch);

    return $token;
  }

  /**
   * Gets Captcha from API Captchetat.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request object.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   HTTP Response for the CaptchEtat element.
   */
  public function getCaptcha(Request $request) {
    $token = $this->generateApiToken();
    $config = $this->configFactory->getEditable('captchetat.settings');
    $request_uri = $request->getRequestUri();
    $query_params = explode('?', $request_uri)[1];
    $url = $config->get('api_url') . '/piste/captcha/simple-captcha-endpoint?' . $query_params;
    $ch = curl_init();
    $headers = [
      "Authorization: Bearer $token",
    ];

    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
      echo 'Curl error: ' . curl_error($ch);
    }

    curl_close($ch);

    return new Response($response);
  }

  /**
   * Validates the user submission.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request object.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   HTTP Response for validation wheter the user entered the correct code.
   */
  public function validationCaptcha(Request $request) {
    $token = $this->generateApiToken();
    $config = $this->configFactory->getEditable('captchetat.settings');
    $payload = $request->getContent();
    $decoded_payload = json_decode($payload, TRUE);
    $url = $config->get('api_url') . '/piste/captcha/valider-captcha';

    $data = [
      'id' => $decoded_payload['captchaId'],
      'code' => $decoded_payload['userEnteredCaptchaCode'],
    ];

    $jsonData = json_encode($data);

    $headers = [
      "Authorization: Bearer $token",
      'Content-Type: application/json',
    ];

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonData);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
      echo 'Curl error: ' . curl_error($ch);
    }

    curl_close($ch);

    return new Response($response);
  }

}
